@@ -1,5 +1,5 @@
 package Weather::OpenWeatherMap;
-$Weather::OpenWeatherMap::VERSION = '0.002004';
+$Weather::OpenWeatherMap::VERSION = '0.003001';
 use strictures 2;
 use Carp;
 
@@ -21,8 +21,7 @@ use Weather::OpenWeatherMap::Result;
 require Weather::OpenWeatherMap::Result::Current;
 require Weather::OpenWeatherMap::Result::Forecast;
 
-
-use Moo; use MooX::late;
+use Moo; 
 
 =pod
 
@@ -117,7 +116,11 @@ sub get_weather {
     $result = Weather::OpenWeatherMap::Result->new_for(
       $type =>
         request => $my_request,
-        json    => $http_response->content
+        json    => $http_response->content,
+        (
+          $my_request->can('hourly') && $my_request->hourly ?
+            (hourly => 1) : ()
+        ),
     );
   }
 
@@ -154,14 +157,15 @@ Weather::OpenWeatherMap - Interface to the OpenWeatherMap API
   );
 
   # Current conditions:
+  # (see Weather::OpenWeatherMap::Result::Current)
   my $current = $wx->get_weather(
     location => 'Manchester, NH',
   );
   my $tempf = $current->temp_f;
   my $wind  = $current->wind_speed_mph;
-  # (see Weather::OpenWeatherMap::Result::Current)
 
-  # Forecast conditions:
+  # Daily forecast conditions:
+  # (see Weather::OpenWeatherMap::Result::Forecast)
   my $forecast = $wx->get_weather(
     location => 'Manchester, NH',
     forecast => 1,
@@ -173,9 +177,22 @@ Weather::OpenWeatherMap - Interface to the OpenWeatherMap API
     my $temp_hi = $day->temp_max_f,
     # (see Weather::OpenWeatherMap::Result::Forecast::Day)
   }
-  # (see Weather::OpenWeatherMap::Result::Forecast)
+
+  # Hourly (3-hr blocks) forecast conditions:
+  my $forecast = $wx->get_weather(
+    location => 'Manchester, NH',
+    forecast => 1,
+    hourly   => 1,
+    days     => 3,
+  );
+  for my $block ($forecast->list) {
+    my $time = $block->dt_txt;
+    my $temp = $block->temp;
+    # (see Weather::OpenWeatherMap::Result::Forecast::Hour)
+  }
 
   # Find a city:
+  # (see Weather::OpenWeatherMap::Result::Find)
   my $search = $wx->get_weather(
     location => 'Manchester',
     find     => 1,
@@ -185,7 +202,6 @@ Weather::OpenWeatherMap - Interface to the OpenWeatherMap API
     my $region = $place->country;
     # ...
   }
-  # (see Weather::OpenWeatherMap::Result::Find)
 
 =head1 DESCRIPTION
 
@@ -257,35 +273,45 @@ control LWP options:
     # omit or set to false for current weather:
     forecast => 1,
 
+    # If 'forecast' is true, you can ask for an hourly (rather than daily)
+    # forecast report:
+    hourly => 1,
+
     # If 'forecast' is true, you can specify the number of days to fetch
-    # (up to 14):
+    # (up to 16 for daily reports, 5 for hourly reports):
     days => 3,
 
     # Optional tag for identifying the response to this request:
     tag  => 'foo',
   );
 
-Request a weather report for the given C<< location => >>.
+Request a weather report (in the form of a L<Weather::OpenWeatherMap::Result>
+object) for the given C<< location => >>.
 
 The location can be a 'City, State' or 'City, Country' string, an
 L<OpenWeatherMap|http://www.openweathermap.org/> city code, or a 'lat X, long
 Y' string.
 
 Requests the current weather by default (see
-L<Weather::OpenWeatherMap::Request::Current>).
+L<Weather::OpenWeatherMap::Request::Current> and
+L<Weather::OpenWeatherMap::Result::Current>).
 
 If passed C<< forecast => 1 >>, requests a weather forecast (see
-L<Weather::OpenWeatherMap::Request::Forecast>), in which case C<< days
-=> $count >> can be specified (up to 14).
+L<Weather::OpenWeatherMap::Request::Forecast> and
+L<Weather::OpenWeatherMap::Result::Forecast>), in which case C<< days =>
+$count >> and/or C<< hourly => $bool >> can be specified.
 
 If passed C<< find => 1 >>, requests search results for a given location name
-or latitude & longitude; see L<Weather::OpenWeatherMap::Request::Find>.
+or latitude & longitude; see L<Weather::OpenWeatherMap::Request::Find> and
+L<Weather::OpenWeatherMap::Result::Find>.
 
 Any extra arguments are passed to the constructor for the appropriate Request
 subclass; see L<Weather::OpenWeatherMap::Request>.
 
 =head1 SEE ALSO
 
+L<Weather::OpenWeatherMap::Result>
+
 L<POEx::Weather::OpenWeatherMap>
 
 =head1 AUTHOR
@@ -293,5 +319,3 @@ L<POEx::Weather::OpenWeatherMap>
 Jon Portnoy <avenj@cobaltirc.org>
 
 =cut
-
-# vim: ts=2 sw=2 et sts=2 ft=perl
