@@ -1,11 +1,11 @@
 package Weather::OpenWeatherMap::Error;
-$Weather::OpenWeatherMap::Error::VERSION = '0.002004';
+$Weather::OpenWeatherMap::Error::VERSION = '0.003001';
 use strictures 2;
 use Carp;
 
 use Types::Standard -all;
 
-use namespace::clean; use Moo; use MooX::late;
+use Moo; 
 
 with 'StackTrace::Auto';
 
