@@ -1,10 +1,10 @@
 package Weather::OpenWeatherMap::Request::Find;
-$Weather::OpenWeatherMap::Request::Find::VERSION = '0.002004';
+$Weather::OpenWeatherMap::Request::Find::VERSION = '0.003001';
 use Carp;
 use URI::Escape 'uri_escape_utf8';
 use Types::Standard -all;
 
-use namespace::clean; use Moo;
+use Moo;
 extends 'Weather::OpenWeatherMap::Request';
 
 has max => (
