@@ -1,5 +1,5 @@
 package Weather::OpenWeatherMap::Result;
-$Weather::OpenWeatherMap::Result::VERSION = '0.002004';
+$Weather::OpenWeatherMap::Result::VERSION = '0.003001';
 use Carp;
 use strictures 2;
 
@@ -10,14 +10,14 @@ use List::Objects::Types -all;
 use Types::Standard      -all;
 
 
-use namespace::clean; use Moo; use MooX::late;
+use Moo; 
 
 use Storable 'freeze';
 
 sub new_for {
   my ($class, $type) = splice @_, 0, 2;
   confess "Expected a subclass type" unless $type;
-  my $subclass = $class .'::'. ucfirst($type);
+  my $subclass = join '::', $class, map ucfirst, split '::', $type;
   use_module($subclass)->new(@_)
 }
 
@@ -172,14 +172,20 @@ Serialization wrapper for use by subclasses.
 
 L<http://www.openweathermap.org/api>
 
-L<Weather::OpenWeatherMap>
-
 L<Weather::OpenWeatherMap::Result::Current>
 
 L<Weather::OpenWeatherMap::Result::Forecast>
 
+L<Weather::OpenWeatherMap::Result::Forecast::Block>
+
+L<Weather::OpenWeatherMap::Result::Forecast::Day>
+
+L<Weather::OpenWeatherMap::Result::Forecast::Hour>
+
 L<Weather::OpenWeatherMap::Result::Find>
 
+L<Weather::OpenWeatherMap::Request>
+
 =head1 AUTHOR
 
 Jon Portnoy <avenj@cobaltirc.org>
