@@ -1,5 +1,5 @@
 package Weather::OpenWeatherMap::Result::Current;
-$Weather::OpenWeatherMap::Result::Current::VERSION = '0.002004';
+$Weather::OpenWeatherMap::Result::Current::VERSION = '0.003001';
 use strictures 2;
 use Carp;
 
@@ -30,7 +30,7 @@ sub lazy_for {
 }
 
 
-use namespace::clean; use Moo; use MooX::late;
+use Moo; 
 extends 'Weather::OpenWeatherMap::Result';
 
 
@@ -300,16 +300,18 @@ The wind direction, in degrees azimuth.
 
 =head1 SEE ALSO
 
-L<http://www.openweathermap.org>
-
-L<Weather::OpenWeatherMap>
+L<http://www.openweathermap.org/current>
 
 L<Weather::OpenWeatherMap::Result>
 
 L<Weather::OpenWeatherMap::Result::Forecast>
 
+L<Weather::OpenWeatherMap::Request>
+
 =head1 AUTHOR
 
 Jon Portnoy <avenj@cobaltirc.org>
 
+Licensed under the same terms as Perl.
+
 =cut
