@@ -1,6 +1,5 @@
 package Weather::OpenWeatherMap::Result::Find;
-$Weather::OpenWeatherMap::Result::Find::VERSION = '0.002004';
-use v5.10;
+$Weather::OpenWeatherMap::Result::Find::VERSION = '0.003001';
 use Carp;
 use strictures 2;
 
@@ -11,7 +10,7 @@ use List::Objects::Types -all;
 use Weather::OpenWeatherMap::Result::Current;
 
 
-use Moo; use MooX::late;
+use Moo; 
 extends 'Weather::OpenWeatherMap::Result';
 
 
