@@ -1,6 +1,5 @@
 package Weather::OpenWeatherMap::Result::Forecast;
-$Weather::OpenWeatherMap::Result::Forecast::VERSION = '0.002004';
-use v5.10;
+$Weather::OpenWeatherMap::Result::Forecast::VERSION = '0.003001';
 use strictures 2;
 use Carp;
 
@@ -8,6 +7,7 @@ use Types::Standard      -all;
 use List::Objects::Types -all;
 
 use Weather::OpenWeatherMap::Result::Forecast::Day;
+use Weather::OpenWeatherMap::Result::Forecast::Hour;
 
 =pod
 
@@ -24,9 +24,12 @@ sub lazy_for {
   )
 }
 
-use namespace::clean; use Moo; use MooX::late;
+use Moo; 
 extends 'Weather::OpenWeatherMap::Result';
 
+has hourly => ( lazy_for Bool,
+  builder => sub { shift->request->hourly ? 1 : 0 },
+);
 
 has id => ( lazy_for Int,
   builder => sub { shift->data->{city}->{id} },
@@ -54,12 +57,22 @@ has count => ( lazy_for Int,
 
 has _forecast_list => ( lazy_for ArrayObj,
   builder => sub { 
-    my @list = @{ shift->data->{list} || [] };
-    [ map {;
+    my ($self) = @_;
+    my @list = @{ $self->data->{list} || [] };
+    warn "No items in forecast list (name: @{[$self->name]})"
+      unless @list;
+    # FIXME test that bad items in @list warn and add nothing
+    $self->request->hourly ?
+      [ map {;
+        ref $_ eq 'HASH' ?
+          Weather::OpenWeatherMap::Result::Forecast::Hour->new(%$_)
+          : (carp "Expected a HASH but got $_" and ())
+      } @list ]
+    : [ map {;
       ref $_ eq 'HASH' ?
         Weather::OpenWeatherMap::Result::Forecast::Day->new(%$_)
-        : carp "expected a HASH but got $_"
-    } @list ]
+        : (carp "expected a HASH but got $_" and ())
+      } @list ]
   },
 );
 
@@ -105,9 +118,13 @@ These are normally emitted by a L<Weather::OpenWeatherMap> instance.
 
 =head2 ATTRIBUTES
 
+=head3 hourly
+
+Boolean true if this is an hourly weather report.
+
 =head3 count
 
-The number of forecasts (days) as returned by the L<OpenWeatherMap
+The number of forecast days returned by the L<OpenWeatherMap
 API|http://www.openweathermap.org/api>.
 
 See L</list> and L</iter>.
@@ -142,8 +159,10 @@ See L</list>.
 
 =head3 list
 
-The full forecast list; each item in the list is a
-L<Weather::OpenWeatherMap::Result::Forecast::Day> instance:
+The full forecast list; each item in the list is either a
+L<Weather::OpenWeatherMap::Result::Forecast::Day> (by default) or a
+L<Weather::OpenWeatherMap::Result::Forecast::Hour> (if L</hourly> is true)
+instance:
 
   for my $day ($result->list) {
     my $date = $day->dt->mdy;
@@ -152,13 +171,15 @@ L<Weather::OpenWeatherMap::Result::Forecast::Day> instance:
   }
 
 See the documentation for
-L<Weather::OpenWeatherMap::Result::Forecast::Day>.
+L<Weather::OpenWeatherMap::Result::Forecast::Day> &
+L<Weather::OpenWeatherMap::Result::Forecast::Hour>.
 
 =head3 iter
 
 Returns an iterator that, when called, returns the next
-L<Weather::OpenWeatherMap::Result::Forecast::Day> instance (or undef
-when the list is empty):
+L<Weather::OpenWeatherMap::Result::Forecast::Day> or
+L<Weather::OpenWeatherMap::Result::Forecast::Hour> instance (or undef when the
+list is empty):
 
   my $iter = $result->iter;
   while (my $day = $iter->()) {
@@ -166,21 +187,18 @@ when the list is empty):
     # ...
   }
 
-See the documentation for
-L<Weather::OpenWeatherMap::Result::Forecast::Day>.
-
 See also: L</list>
 
 =head1 SEE ALSO
 
-L<http://www.openweathermap.org>
-
-L<Weather::OpenWeatherMap>
-
 L<Weather::OpenWeatherMap::Result>
 
+L<Weather::OpenWeatherMap::Result::Forecast::Block>
+
 L<Weather::OpenWeatherMap::Result::Forecast::Day>
 
+L<Weather::OpenWeatherMap::Result::Forecast::Hour>
+
 L<Weather::OpenWeatherMap::Result::Current>
 
 =head1 AUTHOR
