@@ -1,5 +1,5 @@
 package Weather::OpenWeatherMap::Result::Forecast::Day;
-$Weather::OpenWeatherMap::Result::Forecast::Day::VERSION = '0.002004';
+$Weather::OpenWeatherMap::Result::Forecast::Day::VERSION = '0.003001';
 use strictures 2;
 
 use Types::Standard       -all;
@@ -8,15 +8,20 @@ use List::Objects::Types  -all;
 
 use Weather::OpenWeatherMap::Units -all;
 
-use Moo; use MooX::late;
 
-use Storable 'freeze';
+use Moo; 
 
-my $CoercedInt = Int->plus_coercions(StrictNum, sub { int });
-
-has dt => (
+has cloud_coverage => (
+  init_arg  => 'clouds',
   is        => 'ro',
-  isa       => DateTimeUTC,
+  isa       => CoercedInt,
+  coerce    => 1,
+  builder   => sub { 0 },
+);
+
+has humidity => (
+  is        => 'ro',
+  isa       => CoercedInt,
   coerce    => 1,
   builder   => sub { 0 },
 );
@@ -27,26 +32,10 @@ has pressure => (
   builder   => sub { 0 },
 );
 
-has humidity => (
-  is        => 'ro',
-  isa       => $CoercedInt,
-  coerce    => 1,
-  builder   => sub { 0 },
-);
-
-has cloud_coverage => (
-  init_arg  => 'clouds',
-  is        => 'ro',
-  isa       => $CoercedInt,
-  coerce    => 1,
-  builder   => sub { 0 },
-);
-
-
 has wind_speed_mph => (
   init_arg  => 'speed',
   is        => 'ro',
-  isa       => $CoercedInt,
+  isa       => CoercedInt,
   coerce    => 1,
   builder   => sub { 0 },
 );
@@ -54,7 +43,7 @@ has wind_speed_mph => (
 has wind_speed_kph => (
   lazy      => 1,
   is        => 'ro',
-  isa       => $CoercedInt,
+  isa       => CoercedInt,
   coerce    => 1,
   builder   => sub { mph_to_kph shift->wind_speed_mph },
 );
@@ -69,7 +58,7 @@ has wind_direction => (
 has wind_direction_degrees => (
   init_arg  => 'deg',
   is        => 'ro',
-  isa       => $CoercedInt,
+  isa       => CoercedInt,
   coerce    => 1,
   builder   => sub { 0 },
 );
@@ -99,7 +88,7 @@ has temp => (
 has temp_min_f => (
   lazy      => 1,
   is        => 'ro',
-  isa       => $CoercedInt,
+  isa       => CoercedInt,
   coerce    => 1,
   builder   => sub { shift->temp->min },
 );
@@ -107,7 +96,7 @@ has temp_min_f => (
 has temp_max_f => (
   lazy      => 1,
   is        => 'ro',
-  isa       => $CoercedInt,
+  isa       => CoercedInt,
   coerce    => 1,
   builder   => sub { shift->temp->max },
 );
@@ -115,7 +104,7 @@ has temp_max_f => (
 has temp_min_c => (
   lazy      => 1,
   is        => 'ro',
-  isa       => $CoercedInt,
+  isa       => CoercedInt,
   coerce    => 1,
   builder   => sub { f_to_c shift->temp_min_f },
 );
@@ -123,56 +112,13 @@ has temp_min_c => (
 has temp_max_c => (
   lazy      => 1,
   is        => 'ro',
-  isa       => $CoercedInt,
+  isa       => CoercedInt,
   coerce    => 1,
   builder   => sub { f_to_c shift->temp_max_f },
 );
 
 
-
-has _weather_list => (
-  init_arg  => 'weather',
-  is        => 'ro',
-  isa       => ArrayObj,
-  coerce    => 1,
-  builder   => sub { [] },
-);
-
-has _first_weather_item => (
-  lazy      => 1,
-  is        => 'ro',
-  isa       => HashRef,
-  builder   => sub { shift->_weather_list->[0] || +{} },
-);
-
-has conditions_terse => (
-  lazy      => 1,
-  is        => 'ro',
-  isa       => Str,
-  builder   => sub { shift->_first_weather_item->{main} // '' },
-);
-
-has conditions_verbose => (
-  lazy      => 1,
-  is        => 'ro',
-  isa       => Str,
-  builder   => sub { shift->_first_weather_item->{description} // '' },
-);
-
-has conditions_code => (
-  lazy      => 1,
-  is        => 'ro',
-  isa       => Int,
-  builder   => sub { shift->_first_weather_item->{id} // 0 },
-);
-
-has conditions_icon => (
-  lazy      => 1,
-  is        => 'ro',
-  isa       => Maybe[Str],
-  builder   => sub { shift->_first_weather_item->{icon} },
-);
-
+with 'Weather::OpenWeatherMap::Result::Forecast::Block';
 
 
 1;
@@ -181,7 +127,7 @@ has conditions_icon => (
 
 =head1 NAME
 
-Weather::OpenWeatherMap::Result::Forecast::Day
+Weather::OpenWeatherMap::Result::Forecast::Day - Weather report for a single day
 
 =head1 SYNOPSIS
 
@@ -189,100 +135,49 @@ Weather::OpenWeatherMap::Result::Forecast::Day
 
 =head1 DESCRIPTION
 
-A L<Weather::OpenWeatherMap> weather forecast for a single day.
+A L<Weather::OpenWeatherMap> weather forecast for a single day, provided by a
+L<Weather::OpenWeatherMap::Result::Forecast> daily report.
+
+This class consumes L<Weather::OpenWeatherMap::Result::Forecast::Block>; look
+there for other applicable methods and attributes.
 
 =head2 ATTRIBUTES
 
-=head3 Conditions
-
-=head4 cloud_coverage
-
-The forecast cloud coverage, as a percentage.
-
-=head4 conditions_terse
-
-The conditions category.
-
-=head4 conditions_verbose
-
-The conditions description string.
-
-=head4 conditions_code
-
-The L<OpenWeatherMap|http://www.openweathermap.org/> conditions code.
-
-=head4 conditions_icon
-
-The L<OpenWeatherMap|http://www.openweathermap.org/> conditions icon.
-
-=head4 dt
-
-  my $date = $result->dt->mdy;
-
-A L<DateTime> object coerced from the timestamp attached to this forecast.
-
-=head4 humidity
-
-The forecast humidity, as a percentage.
-
-=head4 pressure
-
-The forecast atmospheric pressure, in hPa.
-
-=head3 Temperature
-
-=head4 temp
+=head3 temp
 
 An object containing the returned temperature data; this object provides
 B<morn>, B<night>, B<eve>, B<min>, B<max>, B<day> accessors.
 
 See L</temp_min_f>, L</temp_max_f>.
 
-=head4 temp_min_f
+=head3 temp_min_f
 
 The forecast low temperature, in degrees Fahrenheit.
 
-=head4 temp_max_f
+=head3 temp_max_f
 
 The forecast high temperature, in degrees Fahrenheit.
 
-=head4 temp_min_c
+=head3 temp_min_c
 
 The forecast low temperature, in degrees Celsius.
 
-=head4 temp_max_c
+=head3 temp_max_c
 
 The forecast high temperature, in degrees Celsius.
 
-=head3 Wind
-
-=head4 wind_speed_mph
-
-The forecast wind speed, in MPH.
-
-=head4 wind_speed_kph
-
-The forecast wind speed, in KPH.
-
-=head4 wind_direction
-
-The forecast wind direction, as a (inter-)cardinal direction in the set
-C<< [ N NNE NE ENE E ESE SE SSE S SSW SW WSW W WNW NW NNW ] >>
-
-=head4 wind_direction_degrees
-
-The forecast wind direction, in degrees azimuth.
-
 =head1 SEE ALSO
 
-L<http://www.openweathermap.org>
-
-L<Weather::OpenWeatherMap>
+L<http://www.openweathermap.org/forecast16>
 
 L<Weather::OpenWeatherMap::Result>
 
 L<Weather::OpenWeatherMap::Result::Forecast>
 
+L<Weather::OpenWeatherMap::Result::Forecast::Block>
+
+L<Weather::OpenWeatherMap::Result::Forecast::Hour>
+
 L<Weather::OpenWeatherMap::Result::Current>
 
 =head1 AUTHOR
