@@ -1,12 +1,11 @@
 package Weather::OpenWeatherMap::Test;
-$Weather::OpenWeatherMap::Test::VERSION = '0.002004';
+$Weather::OpenWeatherMap::Test::VERSION = '0.003001';
 =pod
 
 =for Pod::Coverage .*
 
 =cut
 
-use v5.10;
 use strictures 2;
 use Carp;
 
@@ -37,6 +36,11 @@ sub get_test_data {
       last DTYPE
     }
 
+    if ($type eq 'hourly') {
+      $path = dist_file($base, 'hourly.json');
+      last DTYPE
+    }
+
     if ($type eq 'failure' || $type eq 'error') {
       $path = dist_file($base, 'failure.json');
       last DTYPE
@@ -66,19 +70,19 @@ sub get_test_data {
     my $url = $http_request->uri;
     $self->{'__requested'} ? 
       ++$self->{'__requested'} : ($self->{'__requested'} = 1);
-    return $url =~ /forecast/ ?
-      HTTP::Response->new(
-        200 => undef => [] => $self->{forecast_json},
-      )
-      : HTTP::Response->new(
-        200 => undef => [] => $self->{current_json},
-      )
+    if ($url =~ /forecast/) {
+      return $url =~ /daily/ ?
+        HTTP::Response->new( 200 => undef => [] => $self->{forecast_json} )
+        : HTTP::Response->new( 200 => undef => [] => $self->{hourly_json} )
+    }
+    HTTP::Response->new( 200 => undef => [] => $self->{current_json} )
   }
 }
 
 sub mock_http_ua {
   return bless +{
     forecast_json => get_test_data('forecast'),
+    hourly_json   => get_test_data('hourly'),
     current_json  => get_test_data('current'),
   }, 'Weather::OpenWeatherMap::Test::MockUA'
 }
