@@ -1,14 +1,17 @@
 package Weather::OpenWeatherMap::Units;
-$Weather::OpenWeatherMap::Units::VERSION = '0.002004';
+$Weather::OpenWeatherMap::Units::VERSION = '0.003001';
 use feature 'state';
 use strictures 2;
 use Carp;
 
+use Types::Standard  -all;
+
 use parent 'Exporter::Tiny';
 our @EXPORT = our @EXPORT_OK = qw/
   f_to_c
   mph_to_kph
   deg_to_compass
+  CoercedInt
 /;
 
 sub f_to_c { ($_[0] - 32) * (5/9) }
@@ -25,6 +28,10 @@ sub deg_to_compass {
   $compass->[ $val % 16 ]
 }
 
+# FIXME this needs to move to a proper typelib ->
+my $CoercedInt = Int->plus_coercions(StrictNum, sub { int });
+sub CoercedInt { $CoercedInt }
+
 =pod
 
 =for Pod::Coverage .*
